@@ -192,7 +192,7 @@ def input_bot_token(data: DataModel, default=None):
 
 def setup_proxy(data):
     if YesNo(prompt=_("Do you want to run ETM behind a proxy? "),
-             prompt_prefix="[yN] ").launch(default='n'):
+             prompt_prefix="[yN] ", default="n").launch():
         if data.data.get('request_kwargs') is None:
             data.data['request_kwargs'] = {}
         proxy_type = Bullet(prompt=_("Select proxy type"),
@@ -202,7 +202,7 @@ def setup_proxy(data):
         username = None
         password = None
         if YesNo(prompt=_("Does it require authentication? "),
-                 prompt_prefix="[yN] ").launch(default='n'):
+                 prompt_prefix="[yN] ", default="n").launch():
             username = input(_("Username: "))
             password = getpass(_("Password: "))
         if proxy_type == 'http':
@@ -489,8 +489,8 @@ flags_settings = {
 def setup_experimental_flags(data):
     print()
     widget = YesNo(prompt=_("Do you want to config experimental features? "),
-                   prompt_prefix="[yN] ")
-    if not widget.launch(default="n"):
+                   prompt_prefix="[yN] ", default="n")
+    if not widget.launch():
         return
 
     for key, value in flags_settings.items():
@@ -504,8 +504,9 @@ def setup_experimental_flags(data):
             print_wrapped(desc)
 
             ans = YesNo(prompt=f"{key}? ",
+                        default='y' if default else 'n',
                         prompt_prefix=prompt_prefix) \
-                .launch(default='y' if default else 'n')
+                .launch()
 
             data.data['flags'][key] = ans
         elif cat == 'int':
@@ -533,7 +534,8 @@ def setup_network_configurations(data):
     print()
     proceed = YesNo(prompt=_("Do you want to adjust network configurations? "
                              "(connection timeout) "),
-                    prompt_prefix="[yN] ").launch(default='n')
+                    default="n",
+                    prompt_prefix="[yN] ").launch()
     if not proceed:
         return
 
@@ -546,7 +548,7 @@ def setup_network_configurations(data):
     print()
 
     if YesNo(prompt=_("Do you want to change timeout settings? "),
-             prompt_prefix="[yN] ").launch(default='n'):
+             prompt_prefix="[yN] ", default="n").launch():
         if data.data.get('request_kwargs') is None:
             data.data['request_kwargs'] = {}
         data.data['request_kwargs']['read_timeout'] = \
@@ -566,7 +568,7 @@ def setup_rpc(data):
     print()
 
     proceed = YesNo(prompt=_("Do you want to enable RPC interface? "),
-                    prompt_prefix="[yN] ").launch(default='n')
+                    prompt_prefix="[yN] ", default="n").launch()
     if not proceed:
         return
 
